@@ -6,7 +6,7 @@ package Dist::Iller;
 
 # ABSTRACT: A Dist::Zilla & Pod::Weaver preprocessor
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1407';
+our $VERSION = '0.1408';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Map Str ConsumerOf/;
@@ -124,16 +124,16 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-0.1407"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller/0.1407" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Iller%200.1407"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller/0.1407" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-84.5%-orange.svg" alt="coverage 84.5%" />
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-0.1408"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller/0.1408" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller%200.1408"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller/0.1408" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-84.6%-orange.svg" alt="coverage 84.6%" />
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.1407, released 2016-02-18.
+Version 0.1408, released 2016-03-12.
 
 =head1 SYNOPSIS
 
@@ -329,7 +329,7 @@ L<Dist::Iller::Config::Author::CSSON>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/Csson/p5-Dist-Iller>.
+L<https://github.com/Csson/p5-Dist-Iller>
 
 =head1 HOMEPAGE
 
