@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller::DocType::Cpanfile;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1407';
+our $VERSION = '0.1408';
 
 use Dist::Iller::Elk;
 use JSON::MaybeXS qw/decode_json/;
@@ -96,11 +96,11 @@ Dist::Iller::DocType::Cpanfile
 
 =head1 VERSION
 
-Version 0.1407, released 2016-02-18.
+Version 0.1408, released 2016-03-12.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/Csson/p5-Dist-Iller>.
+L<https://github.com/Csson/p5-Dist-Iller>
 
 =head1 HOMEPAGE
 
